summaryrefslogtreecommitdiffstats
path: root/src/cnitemgroup.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-29 16:05:55 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-29 16:05:55 +0000
commit87a016680e3677da3993f333561e79eb0cead7d5 (patch)
treecbda2b4df8b8ee0d8d1617e6c75bec1e3ee0ccba /src/cnitemgroup.h
parent6ce3d1ad09c1096b5ed3db334e02859e45d5c32b (diff)
downloadktechlab-87a016680e3677da3993f333561e79eb0cead7d5.tar.gz
ktechlab-87a016680e3677da3993f333561e79eb0cead7d5.zip
TQt4 port ktechlab
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/ktechlab@1238801 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/cnitemgroup.h')
-rw-r--r--src/cnitemgroup.h27
1 files changed, 14 insertions, 13 deletions
diff --git a/src/cnitemgroup.h b/src/cnitemgroup.h
index fe2c064..397b637 100644
--- a/src/cnitemgroup.h
+++ b/src/cnitemgroup.h
@@ -24,12 +24,12 @@ class Node;
class ECNode;
class FPNode;
class ICNDocument;
-class QCanvasItem;
-class QCanvasItemList;
+class TQCanvasItem;
+class TQCanvasItemList;
-typedef QValueList<QGuardedPtr<Item> > ItemList;
-typedef QValueList<QGuardedPtr<Node> > NodeList;
-typedef QValueList<QGuardedPtr<Connector> > ConnectorList;
+typedef TQValueList<TQGuardedPtr<Item> > ItemList;
+typedef TQValueList<TQGuardedPtr<Node> > NodeList;
+typedef TQValueList<TQGuardedPtr<Connector> > ConnectorList;
/**
@author David Saxton
@@ -37,6 +37,7 @@ typedef QValueList<QGuardedPtr<Connector> > ConnectorList;
class CNItemGroup : public ItemGroup
{
Q_OBJECT
+ TQ_OBJECT
public:
CNItemGroup( ICNDocument *icnDocument, const char *name = 0 );
~CNItemGroup();
@@ -61,11 +62,11 @@ public:
* If the item is a a CNItem, Node or Connector, returns the status
* for that particular add function, else returns false
*/
- virtual bool addQCanvasItem( QCanvasItem *qcanvasItem );
+ virtual bool addTQCanvasItem( TQCanvasItem *qcanvasItem );
/**
* Sets the contained items to those in this list
*/
- virtual void setItems( QCanvasItemList list );
+ virtual void setItems( TQCanvasItemList list );
/**
* Removes the CNItem from the group
*/
@@ -81,11 +82,11 @@ public:
/**
* If the item is a a CNItem, Node or Connector, then attempts to remove it
*/
- virtual void removeQCanvasItem( QCanvasItem *qcanvasItem );
+ virtual void removeTQCanvasItem( TQCanvasItem *qcanvasItem );
/**
* Returns true if the QCanvasItem passed is contained in the group
*/
- virtual bool contains( QCanvasItem *qcanvasItem ) const;
+ virtual bool tqcontains( TQCanvasItem *qcanvasItem ) const;
/**
* Returns the number of Nodes in the CanvasGroup
*/
@@ -137,19 +138,19 @@ public:
/**
* Returns a list of all the Nodes in the group.
* @param excludeParented if false, then nodes that are fully contained
- * within item children will also be returned.
+ * within item tqchildren will also be returned.
*/
NodeList nodes( bool excludeParented = true ) const;
/**
* Returns a list of all the Connectors in the group.
* @param excludeParented if false, then connectors that are fully contained
- * within item children will also be returned.
+ * within item tqchildren will also be returned.
*/
ConnectorList connectors( bool excludeParented = true ) const;
/**
* Returns a list of the ids of all the CNItems in the group.
*/
- QStringList itemIDs();
+ TQStringList itemIDs();
/**
* Returns true if at least some of the CNItems in this group can be
* rotated. Returns false if no items present.
@@ -81,11 +82,11 @@ public:
/**
- * Returns true if the QCanvasItem passed is contained in the group
+ * Returns true if the TQCanvasItem passed is contained in the group
*/